@@ -53,10 +53,10 @@ OC.L10N.register(
     "Remove group" : "Qrupu sil",
     "Repeat" : "Təkrar",
     "never" : "heç vaxt",
+    "Resources" : "Resurslar",
     "Subscribe" : "Abunə",
     "Personal" : "Şəxsi",
-    "Details" : "Detallar",
-    "Resources" : "Resurslar",
+    "Edit event" : "Hadisəni dəyişdir",
     "Close" : "Bağla",
     "Daily" : "Günlük",
     "Weekly" : "Həftəlik",
