@@ -6,11 +6,15 @@ OC.L10N.register(
     "Description:" : "Апісанне:",
     "Date:" : "Дата:",
     "Where:" : "Дзе:",
+    "Event" : "Падзея",
     "Today" : "Сёння",
+    "Year" : "Год",
     "Preview" : "Перадпрагляд",
+    "Copy link" : "Скапіяваць спасылку",
     "Edit" : "Рэдагаваць",
     "Delete" : "Выдаліць",
     "Untitled calendar" : "Каляндар без назвы",
+    "Calendars" : "Календары",
     "Export" : "Экспарт",
     "Name" : "Назва",
     "Deleted" : "Выдалены",
@@ -24,11 +28,13 @@ OC.L10N.register(
     "Cancel" : "Скасаваць",
     "Navigation" : "Навігацыя",
     "Actions" : "Дзеянні",
+    "Close editor" : "Закрыць рэдактар",
     "Enable birthday calendar" : "Уключыць каляндар дзён нараджэння",
     "Show keyboard shortcuts" : "Паказаць спалучэнні клавіш",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} хвіліна","{duration} хвіліны","{duration} хвілін","{duration} хвілін"],
     "_{duration} hour_::_{duration} hours_" : ["{duration} гадзіна","{duration} гадзіны","{duration} гадзін","{duration} гадзін"],
     "_{duration} day_::_{duration} days_" : ["{duration} дзень","{duration} дні","{duration} дзён","{duration} дзён"],
+    "_{duration} week_::_{duration} weeks_" : ["{duration} тыдзень","{duration} тыдні","{duration} тыдняў","{duration} тыдняў"],
     "_{duration} month_::_{duration} months_" : ["{duration} месяц","{duration} месяцы","{duration} месяцаў","{duration} месяцаў"],
     "_{duration} year_::_{duration} years_" : ["{duration} год","{duration} гады","{duration} гадоў","{duration} гадоў"],
     "Update" : "Абнавіць",
@@ -43,9 +49,11 @@ OC.L10N.register(
     "Friday" : "Пятніца",
     "Saturday" : "Субота",
     "Sunday" : "Нядзеля",
+    "Your name" : "Ваша імя",
     "Back" : "Назад",
     "Notification" : "Апавяшчэнне",
     "Email" : "Электронная пошта",
+    "seconds" : "с",
     "Upload from device" : "Запампаваць з прылады",
     "Delete file" : "Выдаліць файл",
     "{attendee} ({role})" : "{attendee} ({role})",
@@ -56,7 +64,10 @@ OC.L10N.register(
     "Decline" : "Адхіліць",
     "Remove group" : "Выдаліць групу",
     "_%n member_::_%n members_" : ["%n удзельнік","%n удзельнікі","%n удзельнікаў","%n удзельнікаў"],
+    "From" : "З",
+    "To" : "Да",
     "never" : "ніколі",
+    "Resources" : "Рэсурсы",
     "Global" : "Глабальны",
     "Public calendars" : "Публічныя календары",
     "Invite" : "Запрасіць",
