@@ -231,7 +231,6 @@ OC.L10N.register(
     "Select conversation" : "Избор на разговор",
     "on" : "на",
     "at" : "в",
-    "Reminder" : "Напомняне",
     "before at" : "преди в",
     "Notification" : "Известие",
     "Email" : "Имейл",
@@ -242,7 +241,6 @@ OC.L10N.register(
     "Edit time" : "Редакирай времето",
     "Save time" : "Запазване на времето",
     "Remove reminder" : "Премахни напомнянето",
-    "+ Add reminder" : "+ Добави напомняне",
     "Add reminder" : "Добавяне на напомняне",
     "seconds" : "секунди",
     "minutes" : "минути",
@@ -270,14 +268,16 @@ OC.L10N.register(
     "Checking availability" : "Проверка на наличността",
     "Has not responded to {organizerName}'s invitation yet" : "Все още няма отговор на поканата на {organizerName}",
     "{organizer} (organizer)" : "{organizer} (organizer)",
+    "Availability of attendees, resources and rooms" : "Наличие на присъстващи, ресурси и стаи",
+    "Legend" : "Легенда",
+    "Out of office" : "Извън офиса",
+    "Attendees:" : "Участници:",
+    "Done" : "Завършено",
+    "Room name" : "Име на стаята",
     "Free" : " Свободни",
     "Busy (tentative)" : "Зает (временно)",
     "Busy" : "Зает",
-    "Out of office" : "Извън офиса",
     "Unknown" : "Непознат",
-    "Availability of attendees, resources and rooms" : "Наличие на присъстващи, ресурси и стаи",
-    "Done" : "Завършено",
-    "Room name" : "Име на стаята",
     "The invitation has been accepted successfully." : "Поканата е приета успешно.",
     "Failed to accept the invitation." : "Неуспешно приемане на поканата.",
     "The invitation has been declined successfully." : "Поканата е отхвърлена успешно.",
@@ -306,7 +306,6 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Не може да се променя целодневната настройка за събития, които са част от набор за повторение.",
     "From" : "От",
     "To" : "До",
-    "All day" : "Цял ден",
     "Repeat" : "Да се повтаря",
     "_time_::_times_" : ["пъти","пъти"],
     "never" : "никога",
@@ -329,7 +328,7 @@ OC.L10N.register(
     "Does not repeat" : "Не се повтаря",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Дефиницията за повторение на това събитие не се поддържа изцяло от Nextcloud. Ако се редактират опциите за повторение, някои повторения могат да бъдат загубени.",
     "No rooms or resources yet" : "Все още няма стаи или ресурси",
-    "Suggestions" : "Препоръки",
+    "Resources" : "Ресурси",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} места","{seatingCapacity} места"],
     "Add resource" : "Добавяне на ресурс",
     "Has a projector" : "Има проектор",
@@ -380,15 +379,15 @@ OC.L10N.register(
     "Personal" : "Лични",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Автоматичното откриване на часовата зона, определи часовата ви зона като UTC.\nТова най-вероятно е резултат от мерките за сигурност на вашия уеб браузър.\nМоля, задайте часовата си зона ръчно в настройките за календар.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Конфигурираната ви часова зона ({timezoneId}) не е намерена. Връщане към UTC.\nМоля, променете часовата си зона в настройките и докладвайте за този проблем.",
+    "Edit event" : "Редакция на събитието",
     "Event does not exist" : "Събитието не съществува",
     "Duplicate" : "Дубликат",
     "Delete this occurrence" : "Изтриване на това събитие",
     "Delete this and all future" : "Изтриване на това и на всички бъдещи ",
-    "Details" : "Подробности",
+    "All day" : "Цял ден",
     "Managing shared access" : "Управление на споделения достъп",
     "Deny access" : "Отказване на достъп",
     "Invite" : "Покани",
-    "Resources" : "Ресурси",
     "_User requires access to your file_::_Users require access to your file_" : ["Потребителите трябва да имат достъп до вашия файл","Потребителите трябва да имат достъп до вашия файл"],
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Прикачени файлове, изискващи споделен достъп","Прикачени файлове, изискващи споделен достъп"],
     "Untitled event" : "Събитие без заглавие",
@@ -476,6 +475,7 @@ OC.L10N.register(
     "Special color of this event. Overrides the calendar-color." : "Специален цвят на това събитие. Сменя цвета на календара.",
     "Error while sharing file" : "Грешка при споделяне на файл",
     "Error while sharing file with user" : "Грешка при споделянето на файл с потребител",
+    "Error creating a folder {folder}" : "Грешка при създаването на папка {folder}",
     "Attachment {fileName} already exists!" : " Прикаченият файл {fileName} вече съществува!",
     "An error occurred during getting file information" : "Възникна грешка при получаването на информация за файла",
     "An error occurred, unable to delete the calendar." : "Възникна грешка, невъзможност да се изтрие календара.",
