@@ -101,6 +101,7 @@ OC.L10N.register(
     "No users or groups" : "Dim defnyddwyr na grwpiau",
     "Unshare from me" : "Dadrannwch oddi wrthyf",
     "Save" : "Cadw",
+    "View" : "Golwg",
     "Import calendars" : "Mewnforio calendrau",
     "Please select a calendar to import into …" : "Dewiswch galendr i fewnforio iddo …",
     "Filename" : "Enw ffeil",
@@ -189,7 +190,6 @@ OC.L10N.register(
     "Could not book the appointment. Please try again later or contact the organizer." : "Methu trefnu apwyntiad. Ceisiwch eto yn nes ymlaen neu cysylltwch â'r trefnydd.",
     "on" : "ar",
     "at" : "am",
-    "Reminder" : "Atgoffwr",
     "before at" : "cyn am",
     "Notification" : "Hysbysiad",
     "Email" : "E-bost",
@@ -200,7 +200,6 @@ OC.L10N.register(
     "Edit time" : "Golygu amser",
     "Save time" : "Arbed amser",
     "Remove reminder" : "Dileu nodyn atgoffa",
-    "+ Add reminder" : "+ Ychwanegu nodyn atgoffa",
     "Add reminder" : "Ychwanegu nodyn atgoffa",
     "seconds" : "eiliad",
     "minutes" : "munud",
@@ -220,12 +219,12 @@ OC.L10N.register(
     "Checking availability" : "Gwirio argaeledd",
     "Has not responded to {organizerName}'s invitation yet" : "Nid yw wedi ymateb i wahoddiad {organizerName} eto",
     "{organizer} (organizer)" : "{organizer} (trefnydd)",
+    "Availability of attendees, resources and rooms" : "Argaeledd mynychwyr, adnoddau ac ystafelloedd",
+    "Out of office" : "Allan o'r swyddfa",
     "Free" : "Am ddim",
     "Busy (tentative)" : "Prysur (o bosib)",
     "Busy" : "Prysur",
-    "Out of office" : "Allan o'r swyddfa",
     "Unknown" : "Anhysbys",
-    "Availability of attendees, resources and rooms" : "Argaeledd mynychwyr, adnoddau ac ystafelloedd",
     "The invitation has been accepted successfully." : "Derbyniwyd y gwahoddiad yn llwyddiannus.",
     "Failed to accept the invitation." : "Methwyd â derbyn y gwahoddiad.",
     "The invitation has been declined successfully." : "Gwrthodwyd y gwahoddiad yn llwyddiannus.",
@@ -250,7 +249,6 @@ OC.L10N.register(
     "Remove color" : "Tynnu lliw",
     "Event title" : "Teitl y digwyddiad",
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Nid oes modd addasu gosodiad diwrnod cyfan ar gyfer digwyddiadau sy'n rhan o set ailadrodd.",
-    "All day" : "Drwy'r dydd",
     "Repeat" : "Ailadrodd",
     "_time_::_times_" : ["amser","gwaith","gwaith","gwaith"],
     "never" : "byth",
@@ -273,7 +271,7 @@ OC.L10N.register(
     "Does not repeat" : "Nid yw'n ailadrodd",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Nid yw Nextcloud yn cefnogi'r diffiniad sy'n ailadrodd y digwyddiad hwn yn llawn. Os ydych chi'n golygu'r opsiynau ailadrodd, mae'n bosibl y byddwch chi'n colli rhai ailadroddiadau.",
     "No rooms or resources yet" : "Dim ystafelloedd nac adnoddau eto",
-    "Suggestions" : "Awgrymiadau",
+    "Resources" : "Adnoddau",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} sedd","{seatingCapacity} sedd","{seatingCapacity} sedd","{seatingCapacity} sedd"],
     "Add resource" : "Ychwanegu adnodd",
     "Has a projector" : "Taflunydd yno",
@@ -323,12 +321,12 @@ OC.L10N.register(
     "Personal" : "Personol",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Penderfynodd y darganfyddiad parth amser awtomatig mai UTC oedd eich parth amser.\nMae hyn yn fwyaf tebygol o ganlyniad i fesurau diogelwch eich porwr gwe.\nGosodwch eich cylchfa amser â llaw yng ngosodiadau'r calendr.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Heb ganfod eich cylchfa amser ffurfweddu ({timezoneId}). Mynd nôl i UTC.\nNewidiwch eich cylchfa amser yn y gosodiadau ac adroddwch am y mater hwn.",
+    "Edit event" : "Golygu digwyddiad",
     "Event does not exist" : "Nid yw'r digwyddiad yn bodoli",
     "Delete this occurrence" : "Dileu'r digwyddiad hwn",
     "Delete this and all future" : "Dileu hwn a phob dyfodol",
-    "Details" : "Manylion",
+    "All day" : "Drwy'r dydd",
     "Invite" : "Gwahoddiad",
-    "Resources" : "Adnoddau",
     "Untitled event" : "Digwyddiad di-deitl",
     "Close" : "Cau",
     "Subscribe to {name}" : "Tanysgrifio i {name}",
