@@ -147,6 +147,7 @@ OC.L10N.register(
     "Share calendar" : "Del kalender",
     "Unshare from me" : "Fjern deling fra mig",
     "Save" : "Gem",
+    "View" : "Vis",
     "Import calendars" : "Importer kalendere",
     "Please select a calendar to import into …" : "Vælg venligst en kalender, der skal importeres til...",
     "Filename" : "Filnavn",
@@ -268,7 +269,6 @@ OC.L10N.register(
     "Add Talk conversation" : "Tilføj Snak samtale",
     "Fetching Talk rooms…" : "Henter Snak rum...",
     "No Talk room available" : "Ingen Snak rum tilgængelige",
-    "Create a new conversation" : "Opret ny samtale",
     "Select conversation" : "Vælg samtale",
     "on" : "på",
     "at" : "ved",
@@ -440,7 +440,6 @@ OC.L10N.register(
     "No valid public calendars configured" : "Ingen gyldige offentlige kalendere konfigureret",
     "Speak to the server administrator to resolve this issue." : "Kontakt venligst serveradministratoren for at løse dette problem.",
     "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Helligdagskalendere leveres af Thunderbird. Kalenderdata vil blive downloadet fra {website}",
-    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "Disse offentlige kalendere er foreslået af serveradministratoren. Kalenderdata vil blive downloadet fra de respektive hjemmesider.",
     "By {authors}" : "Af {authors}",
     "Subscribed" : "Abonneret",
     "Subscribe" : "Tilmeld",
@@ -578,13 +577,6 @@ OC.L10N.register(
     "This is an event reminder." : "Dette er en begivenhedspåmindelse.",
     "Error while parsing a PROPFIND error" : "Fejl under parsing af en PROPFIND-fejl",
     "Appointment not found" : "Aftale ikke fundet",
-    "User not found" : "Bruger ikke fundet",
-    "Reminder" : "Påmindelse",
-    "+ Add reminder" : "+ Tilføj påmindelse",
-    "Select automatic slot" : "Vælg automatisk tidspunkt",
-    "with" : "med",
-    "Available times:" : "Tilgængelige tidspunkter",
-    "Suggestions" : "Forslag",
-    "Details" : "Detaljer"
+    "User not found" : "Bruger ikke fundet"
 },
 "nplurals=2; plural=(n != 1);");
