@@ -45,6 +45,7 @@ OC.L10N.register(
     "Share with users or groups" : "Kunhavigi kun uzantoj aŭ grupoj",
     "No users or groups" : "Neniu uzanto aŭ grupo",
     "Save" : "Konservi",
+    "View" : "Vidi",
     "Filename" : "Dosiernomo",
     "Cancel" : "Nuligi",
     "Automatic" : "Aŭtomata",
@@ -87,10 +88,10 @@ OC.L10N.register(
     "Delete file" : "Forigi dosieron",
     "Available" : "Disponeble",
     "Not available" : "Ne disponeble",
-    "Busy" : "Okupita",
     "Out of office" : "Ekstere oficejo",
-    "Unknown" : "Nekonata",
     "Done" : "Farita",
+    "Busy" : "Okupita",
+    "Unknown" : "Nekonata",
     "Accept" : "Akcepti",
     "Decline" : "Malakcepti",
     "Tentative" : "Nekonfirmita",
@@ -100,7 +101,6 @@ OC.L10N.register(
     "Optional participant" : "Laŭvola partoprenanto",
     "From" : "De",
     "To" : "Al",
-    "All day" : "Tuttage",
     "Repeat" : "Ripeti",
     "never" : "neniam",
     "after" : "post",
@@ -113,13 +113,14 @@ OC.L10N.register(
     "_year_::_years_" : ["Jaro","Jaroj"],
     "weekday" : "Semajntago",
     "weekend day" : "Semajnfintago",
+    "Resources" : "Rimedoj",
     "on {formattedDate}" : "je la {formattedDate}",
     "Global" : "Monda",
     "Subscribe" : "Aboni",
     "Time:" : "Tempo:",
     "Personal" : "Persona",
-    "Details" : "Detaloj",
-    "Resources" : "Rimedoj",
+    "Edit event" : "Redakti okazaĵon",
+    "All day" : "Tuttage",
     "Untitled event" : "Sentitola okazaĵo",
     "Close" : "Fermi",
     "Anniversary" : "Datreveno",
