@@ -147,6 +147,7 @@ OC.L10N.register(
     "Share calendar" : "Compartir calendario",
     "Unshare from me" : "Dejar de compartir conmigo",
     "Save" : "Guardar",
+    "View" : "Ver",
     "Import calendars" : "Importar calendarios",
     "Please select a calendar to import into …" : "Por favor, seleccione un calendario al que importar …",
     "Filename" : "Nombre del archivo",
@@ -398,6 +399,7 @@ OC.L10N.register(
     "Update this occurrence" : "Actualizar esta ocurrencia",
     "Public calendar does not exist" : "El calendario público no existe",
     "Maybe the share was deleted or has expired?" : "¿Quizá el recurso compartido fue eliminado o caducó?",
+    "Maybe" : "Tal vez",
     "from {formattedDate}" : "desde {formattedDate}",
     "to {formattedDate}" : "hasta {formattedDate}",
     "on {formattedDate}" : "el {formattedDate}",
@@ -455,6 +457,7 @@ OC.L10N.register(
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Adjunto que requiere acceso compartido","Adjuntos que requieren acceso compartido","Adjuntos que requieren acceso compartido"],
     "Untitled event" : "Evento sin título",
     "Close" : "Cerrar",
+    "Participants" : "Participantes",
     "Subscribe to {name}" : "Subscribir a {name}",
     "Export {name}" : "Exportar {name}",
     "Anniversary" : "Aniversario",
@@ -546,13 +549,6 @@ OC.L10N.register(
     "This is an event reminder." : "Esto es un recordatorio del evento.",
     "Error while parsing a PROPFIND error" : "Error al analizar un error PROPFIND",
     "Appointment not found" : "Cita no encontrada",
-    "User not found" : "No se encontró el usuario",
-    "Reminder" : "Recordatorio",
-    "+ Add reminder" : "+ Añadir recordatorio",
-    "Select automatic slot" : "Seleccionar un espacio de tiempo automáticamente",
-    "with" : "con",
-    "Available times:" : "Horarios disponibles:",
-    "Suggestions" : "Sugerencias",
-    "Details" : "Detalles"
+    "User not found" : "No se encontró el usuario"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
