@@ -38,6 +38,7 @@ OC.L10N.register(
     "Comment:" : "Comment:",
     "You have a new appointment booking \"%s\" from %s" : "You have a new appointment booking \"%s\" from %s",
     "Dear %s, %s (%s) booked an appointment with you." : "Dear %s, %s (%s) booked an appointment with you.",
+    "Location:" : "مکان:",
     "A Calendar app for Nextcloud" : "یک برنامه تقویم برای نکست کلود",
     "Previous day" : "روز قبل",
     "Previous week" : "هفته قبل",
@@ -139,6 +140,8 @@ OC.L10N.register(
     "Share calendar" : "Share calendar",
     "Unshare from me" : "بی خبر از من",
     "Save" : "ذخیره",
+    "No title" : "No title",
+    "View" : "نمایش",
     "Import calendars" : "وارد کردن تقویم ها",
     "Please select a calendar to import into …" : "لطفاً یک تقویم را برای وارد کردن به… انتخاب کنید",
     "Filename" : "نام پرونده",
@@ -237,7 +240,6 @@ OC.L10N.register(
     "Your email address" : "پست الکترونیکی شما",
     "Could not book the appointment. Please try again later or contact the organizer." : "Could not book the appointment. Please try again later or contact the organizer.",
     "Back" : "Back",
-    "Create a new conversation" : "Create a new conversation",
     "Select conversation" : "مکالمه را انتخاب کنید",
     "on" : "بر",
     "at" : "در",
@@ -359,6 +361,7 @@ OC.L10N.register(
     "Update this occurrence" : "این رویداد را به روز کنید",
     "Public calendar does not exist" : "تقویم عمومی وجود ندارد",
     "Maybe the share was deleted or has expired?" : "شاید اشتراک حذف شده باشد یا منقضی شده باشد؟",
+    "Maybe" : "Maybe",
     "from {formattedDate}" : "از {formattedDate}",
     "to {formattedDate}" : "به {formattedDate}",
     "on {formattedDate}" : "در {formattedDate}",
@@ -408,6 +411,7 @@ OC.L10N.register(
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Attachment requires shared access","Attachments requiring shared access"],
     "Untitled event" : "رویداد بدون عنوان",
     "Close" : "بستن",
+    "Participants" : "شركت كنندگان",
     "Subscribe to {name}" : "اشتراک در {name}",
     "Export {name}" : "دریافت خروجی از {name}",
     "Anniversary" : "سالگرد",
@@ -497,10 +501,6 @@ OC.L10N.register(
     "Imported {filename}" : "وارد شده {نام پرونده}",
     "This is an event reminder." : "This is an event reminder.",
     "Appointment not found" : "Appointment not found",
-    "User not found" : "کاربر یافت نشد",
-    "Reminder" : "Reminder",
-    "+ Add reminder" : "+ اضافه کردن یادآوری",
-    "Suggestions" : "Suggestions",
-    "Details" : "جزئیات"
+    "User not found" : "کاربر یافت نشد"
 },
 "nplurals=2; plural=(n > 1);");
