@@ -37,6 +37,7 @@ OC.L10N.register(
     "Comment:" : "Kommentti:",
     "You have a new appointment booking \"%s\" from %s" : "Sinulla on uusi tapaamisvaraus \"%s\" henkilöltä %s",
     "Dear %s, %s (%s) booked an appointment with you." : "%s, %s (%s) varasi tapaamisen kanssasi.",
+    "Location:" : "Sijainti:",
     "A Calendar app for Nextcloud" : "Kalenterisovellus Nextcloudille",
     "Previous day" : "Edellinen päivä",
     "Previous week" : "Edellinen viikko",
@@ -142,6 +143,8 @@ OC.L10N.register(
     "Share calendar" : "Jaa kalenteri",
     "Unshare from me" : "Lopeta jako minulle",
     "Save" : "Tallenna",
+    "No title" : "Ei otsikkoa",
+    "View" : "Näkymä",
     "Import calendars" : "Tuo kalenterit",
     "Please select a calendar to import into …" : "Valitse kalenteri, johon tuodaan …",
     "Filename" : "Tiedostonimi",
@@ -253,7 +256,6 @@ OC.L10N.register(
     "Select a Talk Room" : "Valitse Talk-huone",
     "Add Talk conversation" : "Lisää Talk-keskustelu",
     "Fetching Talk rooms…" : "Noudetaan Talk-huoneita…",
-    "Create a new conversation" : "Luo uusi keskustelu",
     "Select conversation" : "Valitse keskustelu",
     "on" : "päivä",
     "at" : "kellonaika",
@@ -395,6 +397,7 @@ OC.L10N.register(
     "Update this occurrence" : "Päivitä tämä esiintymä",
     "Public calendar does not exist" : "Julkista kalenteria ei ole olemassa",
     "Maybe the share was deleted or has expired?" : "Kenties jako poistettiin tai se vanheni.",
+    "Maybe" : "Ehkä",
     "from {formattedDate}" : "alkaen {formattedDate}",
     "to {formattedDate}" : "päättyen {formattedDate}",
     "on {formattedDate}" : "päivänä {formattedDate}",
@@ -446,6 +449,7 @@ OC.L10N.register(
     "_User requires access to your file_::_Users require access to your file_" : ["Käyttäjä tarvitsee pääsyn tiedostoosi","Käyttäjät tarvitsevat pääsyn tiedostoosi"],
     "Untitled event" : "Nimetön tapahtuma",
     "Close" : "Sulje",
+    "Participants" : "Osallistujat",
     "Subscribe to {name}" : "Tilaa {name}",
     "Export {name}" : "Vie {name}",
     "Show availability" : "Näytä saatavuus",
@@ -543,12 +547,6 @@ OC.L10N.register(
     "Imported {filename}" : "Tuotiin {filename}",
     "This is an event reminder." : "Tämä on tapahtuman muistutus.",
     "Appointment not found" : "Tapaamista ei löydy",
-    "User not found" : "Käyttäjää ei löydy",
-    "Reminder" : "Muistutus",
-    "+ Add reminder" : "+ Lisää muistutus",
-    "with" : "kanssa",
-    "Available times:" : "Saatavilla olevat ajat:",
-    "Suggestions" : "Ehdotukset",
-    "Details" : "Tiedot"
+    "User not found" : "Käyttäjää ei löydy"
 },
 "nplurals=2; plural=(n != 1);");
