@@ -41,6 +41,8 @@ OC.L10N.register(
     "Comment:" : "Comentario:",
     "You have a new appointment booking \"%s\" from %s" : "Ten unha nova reserva de cita «%s» de %s",
     "Dear %s, %s (%s) booked an appointment with you." : "Estimado %s, %s (%s) reservou unha cita con Vde.",
+    "Location:" : "Lugar:",
+    "Duration:" : "Duración:",
     "A Calendar app for Nextcloud" : "Unha aplicación de calendario para Nextcloud",
     "Previous day" : "Día anterior",
     "Previous week" : "Semana anterior",
@@ -147,6 +149,8 @@ OC.L10N.register(
     "Share calendar" : "Compartir o calendario",
     "Unshare from me" : "Deixar de compartir comigo",
     "Save" : "Gardar",
+    "No title" : "Sen título",
+    "View" : "Ver",
     "Import calendars" : "Importar calendarios",
     "Please select a calendar to import into …" : "Seleccione un calendario para importalo a …",
     "Filename" : "Nome de ficheiro",
@@ -268,7 +272,6 @@ OC.L10N.register(
     "Add Talk conversation" : "Engadir unha conversa de Parladoiro",
     "Fetching Talk rooms…" : "Recuperando salas de Parladoiro…",
     "No Talk room available" : "Non hai ningunha sala de Parladoiro dispoñíbel",
-    "Create a new conversation" : "Crear unha nova conversa",
     "Select conversation" : "Seleccionar conversa",
     "on" : "o",
     "at" : "ás",
@@ -415,6 +418,7 @@ OC.L10N.register(
     "Update this occurrence" : "Actualizar esta recorrencia",
     "Public calendar does not exist" : "O calendario público non existe",
     "Maybe the share was deleted or has expired?" : "Quizais a acción foi eliminada ou caducou.",
+    "Maybe" : "Quizais",
     "from {formattedDate}" : "desde {formattedDate}",
     "to {formattedDate}" : "ata {formattedDate}",
     "on {formattedDate}" : "o {formattedDate}",
@@ -438,7 +442,6 @@ OC.L10N.register(
     "No valid public calendars configured" : "Non se configurou ningún calendario público válido",
     "Speak to the server administrator to resolve this issue." : "Fale coa administración do servidor para resolver este incidente.",
     "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Os calendarios de festivos son fornecidos porThunderbird . Os datos do calendario descargaranse de {website}",
-    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "Estes calendarios públicos son suxeridos pola administración do servidor. Os datos do calendario descargaranse da páxina web correspondente.",
     "By {authors}" : "Por {authors}",
     "Subscribed" : "Subscrito",
     "Subscribe" : "Subscribirse",
@@ -476,6 +479,7 @@ OC.L10N.register(
     "Untitled event" : "Evento sen título",
     "Close" : "Pechar",
     "Modifications will not get propagated to the organizer and other attendees" : "As modificacións non van ser propagadas ao organizador e a outros asistentes",
+    "Participants" : "Participantes",
     "Subscribe to {name}" : "Subscribirse a {name}",
     "Export {name}" : "Exportar {name}",
     "Show availability" : "Amosar a dispoñibilidade",
@@ -575,13 +579,6 @@ OC.L10N.register(
     "This is an event reminder." : "Este é un lembrete de eventos.",
     "Error while parsing a PROPFIND error" : "Produciuse un erro ao analizar un erro PROPFIND",
     "Appointment not found" : "Non se atopou a cita",
-    "User not found" : "Non se atopou o usuario",
-    "Reminder" : "Lembrete",
-    "+ Add reminder" : "+ Engadir lembrete",
-    "Select automatic slot" : "Seleccionar a franxa automática",
-    "with" : "con",
-    "Available times:" : "Horarios dispoñíbeis",
-    "Suggestions" : "Suxestións",
-    "Details" : "Detalles"
+    "User not found" : "Non se atopou o usuario"
 },
 "nplurals=2; plural=(n != 1);");
