@@ -19,6 +19,8 @@ OC.L10N.register(
     "Description:" : "Opis:",
     "Date:" : "Datum:",
     "Where:" : "Gdje:",
+    "Location:" : "Lokacija:",
+    "Duration:" : "Trajanje:",
     "A Calendar app for Nextcloud" : "Aplikacija Kalendar za Nextcloud",
     "Previous day" : "Prethodni dan",
     "Previous week" : "Prethodni tjedan",
@@ -96,6 +98,7 @@ OC.L10N.register(
     "No users or groups" : "Nema korisnika ili grupa",
     "Unshare from me" : "Prekid dijeljenja sa mnom",
     "Save" : "Spremi",
+    "View" : "Pregledaj",
     "Import calendars" : "Uvezi kalendare",
     "Please select a calendar to import into …" : "Odaberite kalendar za uvoz...",
     "Filename" : "Naziv datoteke",
@@ -274,6 +277,7 @@ OC.L10N.register(
     "Invite" : "Poziv",
     "Untitled event" : "Događaj bez naslova",
     "Close" : "Zatvori",
+    "Participants" : "Sudionici",
     "Subscribe to {name}" : "Pretplati se na {name}",
     "Anniversary" : "Godišnjica",
     "Appointment" : "Dogovor",
@@ -357,10 +361,6 @@ OC.L10N.register(
     "Error while sharing file" : "Pogreška pri dijeljenju datoteke",
     "An error occurred, unable to delete the calendar." : "Došlo je do pogreške, nije moguće izbrisati kalendar.",
     "Imported {filename}" : "Uvezena datoteka {filename}",
-    "User not found" : "Korisnik nije pronađen",
-    "Reminder" : "Podsjetnik",
-    "+ Add reminder" : "+ Dodaj podsjetnik",
-    "Suggestions" : "Prijedlozi",
-    "Details" : "Pojedinosti"
+    "User not found" : "Korisnik nije pronađen"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
