@@ -1,12 +1,12 @@
 OC.L10N.register(
     "calendar",
     {
-    "Provided email-address is too long" : "Alamat surel yang diberikan terlalu panjang",
+    "Provided email-address is too long" : "Alamat email yang diberikan terlalu panjang",
     "User-Session unexpectedly expired" : "Sesi-Pengguna kedaluwarsa secara tidak terduga",
-    "Provided email-address is not valid" : "Alamat surel tidak valid",
+    "Provided email-address is not valid" : "Alamat email tidak valid",
     "%s has published the calendar »%s«" : "%s telah mempublikasikan kalender »%s«",
-    "Unexpected error sending email. Please contact your administrator." : "Galat saat mengirim surel. Silakan hubungi administrator Anda.",
-    "Successfully sent email to %1$s" : "Berhasil mengirim surel ke %1$s",
+    "Unexpected error sending email. Please contact your administrator." : "Galat saat mengirim email. Silakan hubungi administrator Anda.",
+    "Successfully sent email to %1$s" : "Berhasil mengirim email ke %1$s",
     "Hello," : "Halo,",
     "We wanted to inform you that %s has published the calendar »%s«." : "Kami ingin menginformasikan Anda bahwa %s telah mempublikasikan kalender »%s«.",
     "Open »%s«" : "Buka »%s«",
@@ -27,16 +27,17 @@ OC.L10N.register(
     "Dear %s, please confirm your booking" : "Kepada %s, mohon konfirmasi pemesanan Anda",
     "Confirm" : "Konfirmasi",
     "This confirmation link expires in %s hours." : "Tautan konfirmasi ini akan kedaluwarsa dalam %s jam.",
-    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Jika Anda ingin membatalkan janji temu, mohon hubungi penyelenggara Anda dengan membalas surel ini atau mengunjungi halaman profil mereka",
+    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Jika Anda ingin membatalkan janji temu, mohon hubungi penyelenggara Anda dengan membalas email ini atau mengunjungi halaman profil mereka",
     "Your appointment \"%s\" with %s has been accepted" : "Janji temu \"%s\" dengan %stelah diterima",
     "Dear %s, your booking has been accepted." : "Kepada %s, pemesanan Anda telah diterima.",
     "Appointment for:" : "Janji temu untuk:",
     "Date:" : "Tanggal:",
-    "You will receive a link with the confirmation email" : "Anda akan menerima tautan dengan surel konfirmasi",
+    "You will receive a link with the confirmation email" : "Anda akan menerima tautan dengan email konfirmasi",
     "Where:" : "Tempat:",
     "Comment:" : "Komentar:",
     "You have a new appointment booking \"%s\" from %s" : "Anda memiliki pemesanan janji temu baru \"%s\" dari %s",
     "Dear %s, %s (%s) booked an appointment with you." : "Kepada %s, %s (%s) memesan janji temu dengan Anda.",
+    "Location:" : "Lokasi:",
     "A Calendar app for Nextcloud" : "Aplikasi Kalender untuk Nextcloud",
     "Previous day" : "Hari sebelum",
     "Previous week" : "Minggu sebelum",
@@ -109,14 +110,14 @@ OC.L10N.register(
     "Deck" : "Longgok",
     "Hidden" : "Sembunyi",
     "An error occurred, unable to publish calendar." : "Terjadi galat, tidak dapat menerbitkan kalender.",
-    "An error occurred, unable to send email." : "Terjadi galat, tidak dapat mengirim surel.",
+    "An error occurred, unable to send email." : "Terjadi galat, tidak dapat mengirim email.",
     "Embed code copied to clipboard." : "Kode tersemat disalin ke papan klip",
     "Embed code could not be copied to clipboard." : "Kode tersemat tidak dapat disalin ke papan klip.",
     "Unpublishing calendar failed" : "Gagal membatalkan penerbitan kalender",
     "Share link" : "Bagikan tautan",
     "Copy public link" : "Salin tautan publik",
-    "Send link to calendar via email" : "Kirim tautan kalender via surel",
-    "Sending email …" : "Mengirim surel …",
+    "Send link to calendar via email" : "Kirim tautan kalender via email",
+    "Sending email …" : "Mengirim email …",
     "Copy embedding code" : "Salin kode penyemat",
     "Copying code …" : "Menyalin kode …",
     "Copied code" : "Kode tersalin",
@@ -130,6 +131,7 @@ OC.L10N.register(
     "Share with users or groups" : "Berbagi dengan pengguna atau grup",
     "No users or groups" : "Tidak ada pengguna atau grup",
     "Save" : "Simpan",
+    "View" : "Tampilan",
     "Import calendars" : "Impor kalender",
     "Filename" : "Nama berkas",
     "Cancel" : "Batal",
@@ -165,7 +167,9 @@ OC.L10N.register(
     "Copy primary CalDAV address" : "Salin alamat utama CalDAV",
     "Copy iOS/macOS CalDAV address" : "Salin alamat CalDAV iOS/macOS",
     "Show keyboard shortcuts" : "Tampilkan pintasan papan kunci",
-    "To configure appointments, add your email address in personal settings." : "Untuk mengonfigurasi janji temu, tambahkan alamat surel Anda di pengaturan pribadi.",
+    "_{duration} minute_::_{duration} minutes_" : ["{duration} menit"],
+    "_{duration} hour_::_{duration} hours_" : ["{duration} jam"],
+    "To configure appointments, add your email address in personal settings." : "Untuk mengonfigurasi janji temu, tambahkan alamat email Anda di pengaturan pribadi.",
     "Update" : "Perbarui",
     "Location" : "Lokasi",
     "Description" : "Deskrisi",
@@ -178,13 +182,13 @@ OC.L10N.register(
     "Friday" : "Jumat",
     "Saturday" : "Sabtu",
     "Sunday" : "Minggu",
-    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Kami telah mengirim surel dengan detailnya. Mohon konfirmasikan janji temu Anda menggunakan tautan dalam surel tersebut. Anda dapat menutup halaman ini sekarang.",
-    "Your email address" : "Alamat surel Anda",
+    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Kami telah mengirim email dengan detailnya. Mohon konfirmasikan janji temu Anda menggunakan tautan dalam email tersebut. Anda dapat menutup halaman ini sekarang.",
+    "Your email address" : "Alamat email Anda",
     "Could not book the appointment. Please try again later or contact the organizer." : "Tidak dapat memesan janji temu. Mohon coba lagi nanti atau hubungi penyelenggara.",
     "on" : "pada",
     "at" : "di",
     "Notification" : "Notifikasi",
-    "Email" : "Surel",
+    "Email" : "Email",
     "Audio notification" : "Notifikasi audio",
     "Other notification" : "Notifikasi lain",
     "Relative to event" : "Relatif terhadap acara",
@@ -192,7 +196,6 @@ OC.L10N.register(
     "Edit time" : "Edit waktu",
     "Save time" : "Simpan waktu",
     "Remove reminder" : "Buang pengingat",
-    "+ Add reminder" : "+ Tambah pengingat",
     "seconds" : "detik",
     "minutes" : "menit",
     "hours" : "jam",
@@ -201,14 +204,14 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "Pilih berkas untuk ditambahkan sebagai lampiran",
     "Delete file" : "Hapus berkas",
     "Not available" : "Tidak tersedia",
+    "Availability of attendees, resources and rooms" : "Ketersediaan peserta, sumber daya, dan ruangan",
+    "Out of office" : "Keluar kantor",
+    "Done" : "Selesai",
+    "Room name" : "Nama ruang",
     "Free" : "Luang",
     "Busy (tentative)" : "Sibuk (tentatif)",
     "Busy" : "Sibuk",
-    "Out of office" : "Keluar kantor",
     "Unknown" : "Tidak diketahui",
-    "Availability of attendees, resources and rooms" : "Ketersediaan peserta, sumber daya, dan ruangan",
-    "Done" : "Selesai",
-    "Room name" : "Nama ruang",
     "The invitation has been accepted successfully." : "Undangan berhasil diterima.",
     "Failed to accept the invitation." : "Gagal menerima undangan.",
     "The invitation has been declined successfully." : "Undangan berhasil ditolak.",
@@ -230,11 +233,10 @@ OC.L10N.register(
     "No match found" : "Tidak ditemukan kecocokan",
     "Note that members of circles get invited but are not synced yet." : "Perhatikan bahwa anggota kelompok diundang tapi belum tersinkronisasi.",
     "(organizer)" : "(penyelenggara)",
-    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Untuk mengirim undangan dan mengurus respons, [linkopen]tambahkan alamat surel Anda di pengaturan pribadi[linkclose].",
+    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Untuk mengirim undangan dan mengurus respons, [linkopen]tambahkan alamat email Anda di pengaturan pribadi[linkclose].",
     "Remove color" : "Hapus warna",
     "Event title" : "Judul acara",
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Tidak dapat mengubah pengaturan sehari penuh untuk acara yang merupakan bagian dari set pengulangan.",
-    "All day" : "Sepanjang hari",
     "Repeat" : "Ulang",
     "never" : "tidak pernah",
     "on date" : "pada tanggal",
@@ -254,8 +256,11 @@ OC.L10N.register(
     "weekday" : "akhir pekan",
     "weekend day" : "akhir pekan",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Penentuan perulangan acara ini tidak sepenuhnya didukung oleh Nextcloud. Jika Anda mengedit opsi pengulangan, pengulangan tertentu mungkin hilang.",
+    "Resources" : "Sumber daya",
     "Public calendar does not exist" : "Kalender publik tidak eksis",
     "Maybe the share was deleted or has expired?" : "Mungkin yang dibagikan terhapus atau kadaluwarsa?",
+    "Create" : "Buat",
+    "on {formattedDate}" : "dalam {formattedDate}",
     "Please enter a valid date" : "Silakan isi tanggal valid",
     "Please enter a valid date and time" : "Silakan isi tanggal dan waktu valid",
     "Pick a time" : "Pilih waktu",
@@ -264,15 +269,14 @@ OC.L10N.register(
     "An error occurred, unable to subscribe to calendar." : "Terjadi kesalahan, tidak dapat berlangganan kalender.",
     "Speak to the server administrator to resolve this issue." : "Hubungi administrator server untuk menyelesaikan masalah ini.",
     "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Kalender hari libur nasional disediakan oleh Thunderbird. Data kalender akan diunduh dari {website}",
-    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "Kalender-kalender umum ini disarankan oleh administrator server. data Kalender akan diunduh dari situs web masing-masing.",
     "Subscribe" : "Berlangganan",
     "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Terima kasih. Pemesanan Anda dari {startDate} hingga  {endDate} telah dikonfirmasi.",
     "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Slot untuk janji temu Anda dari {startDate} hingga {endDate} tidak lagi tersedia.",
     "Personal" : "Pribadi",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Deteksi zona waktu otomatis menetapkan UTC sebagai zona waktu Anda. Hal ini kemungkinan besar disebabkan oleh langkah keamanan peramban web Anda. Harap setel zona waktu Anda secara manual di pengaturan kalender.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Zona waktu Anda yang terkonfigurasi ({timezoneId}) tidak ditemukan. Kembali ke UTC.\nHarap ubah zona waktu Anda di pengaturan dan laporkan masalah ini.",
-    "Details" : "Detail",
-    "Resources" : "Sumber daya",
+    "Edit event" : "Sunting agenda",
+    "All day" : "Sepanjang hari",
     "Untitled event" : "Acara tanpa judul",
     "Close" : "Tutup",
     "Subscribe to {name}" : "Berlangganan ke {name}",
