@@ -41,6 +41,7 @@ OC.L10N.register(
     "Comment:" : "Athugasemd:",
     "You have a new appointment booking \"%s\" from %s" : "Þú ert með nýja bókun um \"%s\" stefnumót frá %s",
     "Dear %s, %s (%s) booked an appointment with you." : "Kæri/Kæra %s, %s (%s) bókaði fund með þér.",
+    "Location:" : "Staðsetning:",
     "A Calendar app for Nextcloud" : "Dagatalsforrit fyrir Nextcloud",
     "Previous day" : "Fyrri dagur",
     "Previous week" : "Fyrri vika",
@@ -147,6 +148,7 @@ OC.L10N.register(
     "Share calendar" : "Deila dagatali",
     "Unshare from me" : "Hætta deilingu frá mér",
     "Save" : "Vista",
+    "View" : "Skoða",
     "Import calendars" : "Flytja inn dagatöl",
     "Please select a calendar to import into …" : "Veldu dagatal til að flytja inn í …",
     "Filename" : "Skráarheiti",
@@ -268,11 +270,9 @@ OC.L10N.register(
     "Add Talk conversation" : "Bæta við samtali á spjallrás",
     "Fetching Talk rooms…" : "Sæki spjallrásir…",
     "No Talk room available" : "Engin spjallrás tiltæk",
-    "Create a new conversation" : "Hefja nýtt samtal",
     "Select conversation" : "Veldu samtal",
     "on" : "þann",
     "at" : "klukkan",
-    "Reminder" : "Áminning",
     "before at" : "á undan klukkan",
     "Notification" : "Tilkynning",
     "Email" : "Tölvupóstur",
@@ -283,7 +283,6 @@ OC.L10N.register(
     "Edit time" : "Breyta tíma",
     "Save time" : "Vista tíma",
     "Remove reminder" : "Fjarlægja áminningu",
-    "+ Add reminder" : "+ Bæta við áminningu",
     "Add reminder" : "Bæta við áminningu",
     "seconds" : "sekúndum",
     "minutes" : "mínútur",
@@ -318,26 +317,24 @@ OC.L10N.register(
     "Awaiting response" : "Bíður eftir svari",
     "Checking availability" : "Athuga hvað sé á lausu",
     "Has not responded to {organizerName}'s invitation yet" : "Hefur ekki svarað boðinu frá {organizerName} ennþá",
-    "Select automatic slot" : "Velja sjálfvirkt tímahólf",
     "chairperson" : "fundarstjóri",
     "required participant" : "nauðsynlegur þátttakandi",
     "non-participant" : "ekki þátttakandi",
     "optional participant" : "aukaþátttakandi",
     "{organizer} (organizer)" : "{organizer} (organizer)",
     "{attendee} ({role})" : "{attendee} ({role})",
-    "Free" : "Laus",
-    "Busy (tentative)" : "Upptekinn (með fyrirvara)",
-    "Busy" : "Upptekinn",
-    "Out of office" : "Ekki á staðnum",
-    "Unknown" : "Óþekkt",
     "Availability of attendees, resources and rooms" : "Framboð á þátttakendum, tilföngum og herbergjum",
-    "with" : "með",
-    "Available times:" : "Lausir tímar:",
     "Suggestion accepted" : "Tillaga samþykkt",
+    "Out of office" : "Ekki á staðnum",
+    "Attendees:" : "Þáttakendur:",
     "Done" : "Lokið",
     "Search room" : "Leita að aðstöðu",
     "Room name" : "Heiti fundarsalar",
     "Check room availability" : "Athuga framboð",
+    "Free" : "Laus",
+    "Busy (tentative)" : "Upptekinn (með fyrirvara)",
+    "Busy" : "Upptekinn",
+    "Unknown" : "Óþekkt",
     "Find a time" : "Finna tíma",
     "The invitation has been accepted successfully." : "Boðið hefur verið samþykkt.",
     "Failed to accept the invitation." : "Mistókst að samþykkja boðið.",
@@ -375,7 +372,6 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Get ekki breytt heils-dags-stillingu viðburða sem eru hluti af endurtekningasetti.",
     "From" : "Frá",
     "To" : "Til",
-    "All day" : "Heilsdagsviðburður",
     "Repeat" : "Endurtaka",
     "_time_::_times_" : ["sinni","sinnum"],
     "never" : "aldrei",
@@ -398,7 +394,7 @@ OC.L10N.register(
     "Does not repeat" : "Endurtekst ekki",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Endurtekninga-skilgreining þessa viðburðar er ekki að fullu studd í Nextcloud. Ef þú breytir endurtekninga-valkostunum, gætu sumar endurtekningar tapast.",
     "No rooms or resources yet" : "Ennþá ekki neinir salir eða tilföng",
-    "Suggestions" : "Tillögur",
+    "Resources" : "Tilföng",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} sæti","{seatingCapacity} sæti"],
     "Add resource" : "Bæta við tilfangi",
     "Has a projector" : "Er með skjávarpa",
@@ -419,6 +415,7 @@ OC.L10N.register(
     "Update this occurrence" : "Uppfæra þetta tilviki",
     "Public calendar does not exist" : "Opinbert dagatal er ekki til",
     "Maybe the share was deleted or has expired?" : "Hugsanlega hefur sameigninni verið eytt eða hún sé útrunnin?",
+    "Create" : "Búa til",
     "from {formattedDate}" : "frá {formattedDate}",
     "to {formattedDate}" : "til {formattedDate}",
     "on {formattedDate}" : "þann {formattedDate}",
@@ -442,7 +439,6 @@ OC.L10N.register(
     "No valid public calendars configured" : "Engin gild opinber dagatöl stillt",
     "Speak to the server administrator to resolve this issue." : "Hafðu samband við kerfisstjóra netþjónsins til að leysa þetta.",
     "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Dagatöl með opinberum frídögum koma frá Thunderbird. Dagatalsgögnin eru sótt frá {website}",
-    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "Þessar tillögur að opinberum dagatölum koma frá stjórnanda netþjónsins. Gögn dagatalanna verða sótt inn á viðkomandi vefsvæði.",
     "By {authors}" : "Frá {authors}",
     "Subscribed" : "Í áskrift",
     "Subscribe" : "Gerast áskrifandi",
@@ -465,19 +461,20 @@ OC.L10N.register(
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Sjálfvirka tímabeltisgreiningin ákvarðaði tímabeltið þitt sem UTC.\nLíklega er það vegna öryggisstillinga í vafranum þínum.\nStilltu tímabeltið þitt í stillingum dagatalsins.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Stillta tímabeltið þitt ({timezoneId}) fannst ekki. Nota UTC til vara.\nStilltu tímabeltið þitt í stillingum dagatalsins og tilkynntu þetta vandamál.",
     "Availability of {displayName}" : "Lausir tímar hjá {displayName}",
+    "Edit event" : "Breyta atburði",
     "Event does not exist" : "Atburður er ekki til",
     "Duplicate" : "Tvítaka",
     "Delete this occurrence" : "Eyða þessu tilviki",
     "Delete this and all future" : "Eyða þessu og framtíðar tilvikum",
-    "Details" : "Nánar",
+    "All day" : "Heilsdagsviðburður",
     "Managing shared access" : "Sýsla með sameiginlegan aðgang",
     "Deny access" : "Hafna aðgangi",
     "Invite" : "Bjóða",
-    "Resources" : "Tilföng",
     "_User requires access to your file_::_Users require access to your file_" : ["Notandi þarf aðgang að skránni þinni","Notendur þurfa aðgang að skránni þinni"],
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Viðhengi krefst sameiginlegs aðgangs","Viðhengi krefjast sameiginlegs aðgangs"],
     "Untitled event" : "Ónefndur atburður",
     "Close" : "Loka",
+    "Participants" : "Þátttakendur",
     "Subscribe to {name}" : "Panta áskrift að {name}",
     "Export {name}" : "Flytja út {name}",
     "Show availability" : "Sýna lausa tíma",
