@@ -40,6 +40,7 @@ OC.L10N.register(
     "Comment:" : "Comment:",
     "You have a new appointment booking \"%s\" from %s" : "You have a new appointment booking \"%s\" from %s",
     "Dear %s, %s (%s) booked an appointment with you." : "Dear %s, %s (%s) booked an appointment with you.",
+    "Location:" : "Location:",
     "A Calendar app for Nextcloud" : "A Calendar app for Nextcloud",
     "Previous day" : "Previous day",
     "Previous week" : "Previous week",
@@ -142,6 +143,7 @@ OC.L10N.register(
     "Share calendar" : "Share calendar",
     "Unshare from me" : "Unshare from me",
     "Save" : "Save",
+    "View" : "View",
     "Import calendars" : "Import calendars",
     "Please select a calendar to import into …" : "Please select a calendar to import into …",
     "Filename" : "Filename",
@@ -241,11 +243,9 @@ OC.L10N.register(
     "Please share anything that will help prepare for our meeting" : "Please share anything that will help prepare for our meeting",
     "Could not book the appointment. Please try again later or contact the organizer." : "Could not book the appointment. Please try again later or contact the organizer.",
     "Back" : "Back",
-    "Create a new conversation" : "Create a new conversation",
     "Select conversation" : "Select conversation",
     "on" : "on",
     "at" : "at",
-    "Reminder" : "Reminder",
     "before at" : "before at",
     "Notification" : "Notification",
     "Email" : "Email",
@@ -256,7 +256,6 @@ OC.L10N.register(
     "Edit time" : "Edit time",
     "Save time" : "Save time",
     "Remove reminder" : "Remove reminder",
-    "+ Add reminder" : "+ Add reminder",
     "Add reminder" : "Add reminder",
     "seconds" : "seconds",
     "minutes" : "minutes",
@@ -284,13 +283,14 @@ OC.L10N.register(
     "Checking availability" : "Checking availability",
     "Has not responded to {organizerName}'s invitation yet" : "Has not responded to {organizerName}'s invitation yet",
     "{organizer} (organizer)" : "{organizer} (organizer)",
+    "Availability of attendees, resources and rooms" : "Availability of attendees, resources and rooms",
+    "Out of office" : "Out of office",
+    "Attendees:" : "Attendees:",
+    "Done" : "Done",
     "Free" : "Free",
     "Busy (tentative)" : "Busy (tentative)",
     "Busy" : "Busy",
-    "Out of office" : "Out of office",
     "Unknown" : "Unknown",
-    "Availability of attendees, resources and rooms" : "Availability of attendees, resources and rooms",
-    "Done" : "Done",
     "The invitation has been accepted successfully." : "The invitation has been accepted successfully.",
     "Failed to accept the invitation." : "Failed to accept the invitation.",
     "The invitation has been declined successfully." : "The invitation has been declined successfully.",
@@ -321,7 +321,6 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Cannot modify all-day setting for events that are part of a recurrence-set.",
     "From" : "From",
     "To" : "To",
-    "All day" : "All day",
     "Repeat" : "Repeat",
     "_time_::_times_" : ["time","times"],
     "never" : "never",
@@ -344,7 +343,7 @@ OC.L10N.register(
     "Does not repeat" : "Does not repeat",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost.",
     "No rooms or resources yet" : "No rooms or resources yet",
-    "Suggestions" : "Suggestions",
+    "Resources" : "Resources",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} seat","{seatingCapacity} seats"],
     "Add resource" : "Add resource",
     "Has a projector" : "Has a projector",
@@ -363,6 +362,8 @@ OC.L10N.register(
     "Update this occurrence" : "Update this occurrence",
     "Public calendar does not exist" : "Public calendar does not exist",
     "Maybe the share was deleted or has expired?" : "Maybe the share was deleted or has expired?",
+    "Remove participant" : "Remove participant",
+    "Create" : "Create",
     "from {formattedDate}" : "from {formattedDate}",
     "to {formattedDate}" : "to {formattedDate}",
     "on {formattedDate}" : "on {formattedDate}",
@@ -385,7 +386,6 @@ OC.L10N.register(
     "No valid public calendars configured" : "No valid public calendars configured",
     "Speak to the server administrator to resolve this issue." : "Speak to the server administrator to resolve this issue.",
     "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}",
-    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website.",
     "By {authors}" : "By {authors}",
     "Subscribed" : "Subscribed",
     "Subscribe" : "Subscribe",
@@ -410,15 +410,16 @@ OC.L10N.register(
     "Duplicate" : "Duplicate",
     "Delete this occurrence" : "Delete this occurrence",
     "Delete this and all future" : "Delete this and all future",
-    "Details" : "Details",
+    "All day" : "All day",
     "Managing shared access" : "Managing shared access",
     "Deny access" : "Deny access",
     "Invite" : "Invite",
-    "Resources" : "Resources",
     "_User requires access to your file_::_Users require access to your file_" : ["User requires access to your file","Users require access to your file"],
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Attachment requires shared access","Attachments requiring shared access"],
     "Untitled event" : "Untitled event",
     "Close" : "Close",
+    "Selected" : "Selected",
+    "Participants" : "Participants",
     "Subscribe to {name}" : "Subscribe to {name}",
     "Export {name}" : "Export {name}",
     "Anniversary" : "Anniversary",
