@@ -39,6 +39,7 @@ OC.L10N.register(
     "Comment:" : "댓글:",
     "You have a new appointment booking \"%s\" from %s" : "%s님으로부터 약속 \"%s\"에 대한 새로운 예약이 있습니다",
     "Dear %s, %s (%s) booked an appointment with you." : "%s님,  %s(%s)님께서 귀하와 약속을 예약했습니다.",
+    "Location:" : "위치:",
     "A Calendar app for Nextcloud" : "Nextcloud 달력 앱",
     "Previous day" : "이전날",
     "Previous week" : "이전주",
@@ -141,6 +142,8 @@ OC.L10N.register(
     "Share calendar" : "달력 공유",
     "Unshare from me" : "나의 공유 해제",
     "Save" : "저장",
+    "No title" : "제목 없음",
+    "View" : "보기",
     "Import calendars" : "달력 가져오기",
     "Please select a calendar to import into …" : "다음으로 가져올 달력을 선택해 주십시오 ...",
     "Filename" : "파일 이름",
@@ -246,11 +249,9 @@ OC.L10N.register(
     "Could not book the appointment. Please try again later or contact the organizer." : "예약할 수 없음. 잠시 후 다시 시도하거나 중재자에게 문의하십시오.",
     "Back" : "뒤로",
     "Book appointment" : "약속 잡기",
-    "Create a new conversation" : "새 대화 만들기",
     "Select conversation" : "대화 선택",
     "on" : "다음 시간/위치에: ",
     "at" : "다음 시간/위치에: ",
-    "Reminder" : "알림",
     "before at" : "다음 이전에: ",
     "Notification" : "알림",
     "Email" : "이메일",
@@ -261,7 +262,6 @@ OC.L10N.register(
     "Edit time" : "시간 편집",
     "Save time" : "시간 저장",
     "Remove reminder" : "알림 삭제",
-    "+ Add reminder" : "+ 알림 생성",
     "Add reminder" : "알림 추가",
     "seconds" : "초",
     "minutes" : "분",
@@ -291,14 +291,15 @@ OC.L10N.register(
     "Checking availability" : "시간 조율 설정 확인 중",
     "Has not responded to {organizerName}'s invitation yet" : "{organizerName}의 초대에 아직 응답하지 않음",
     "{organizer} (organizer)" : "{organizer} (주회자)",
+    "Availability of attendees, resources and rooms" : "참석 가능한 시간대 및 자원, 호실 사용 가능 여부 확인",
+    "Out of office" : "자리에 없음",
+    "Attendees:" : "참석자:",
+    "Done" : "완료",
+    "Room name" : "방 번호",
     "Free" : "바쁘지 않음",
     "Busy (tentative)" : "바쁨 (잠정적으로)",
     "Busy" : "바쁨",
-    "Out of office" : "자리에 없음",
     "Unknown" : "알 수 없음",
-    "Availability of attendees, resources and rooms" : "참석 가능한 시간대 및 자원, 호실 사용 가능 여부 확인",
-    "Done" : "완료",
-    "Room name" : "방 번호",
     "The invitation has been accepted successfully." : "초대가 성공적으로 수락됨",
     "Failed to accept the invitation." : "초대를 수락할 수 없음",
     "The invitation has been declined successfully." : "초대가 성공적으로 거절됨",
@@ -329,7 +330,6 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "반복하는 이 일정의 \"하루 종일\" 여부를 수정할 수 없습니다.",
     "From" : "시작",
     "To" : "종료",
-    "All day" : "하루 종일",
     "Repeat" : "반복",
     "_time_::_times_" : ["회"],
     "never" : "없음",
@@ -351,7 +351,7 @@ OC.L10N.register(
     "Does not repeat" : "반복하지 않음",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Nextcloud에서 이 일정의 반복 설정 방식을 완전히 지원하지 않습니다. 반복 설정을 편집할 경우, 현재의 반복 설정이 사라질 수 있습니다.",
     "No rooms or resources yet" : "호실 혹은 비품 없음",
-    "Suggestions" : "제안",
+    "Resources" : "자원",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity}석"],
     "Add resource" : "비품 추가",
     "Has a projector" : "프로젝터 있음",
@@ -369,6 +369,8 @@ OC.L10N.register(
     "Update this occurrence" : "이 일정 업데이트",
     "Public calendar does not exist" : "공용 달력이 존재하지 않음",
     "Maybe the share was deleted or has expired?" : "공유가 삭제되었거나 만료되었을 수 있습니다.",
+    "Maybe" : "아마도",
+    "Create" : "생성",
     "from {formattedDate}" : "{formattedDate} 부터",
     "to {formattedDate}" : "{formattedDate} 까지",
     "on {formattedDate}" : "{formattedDate}에",
@@ -391,7 +393,6 @@ OC.L10N.register(
     "No valid public calendars configured" : "설정된 유효한 달력 없음",
     "Speak to the server administrator to resolve this issue." : "이 문제를 해결하기 위해 서버 관리자에게 문의하십시오",
     "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "공개 휴일 달력은 Thunderbird에서 제공합니다. 달력의 데이터는 {website}(으)로부터 다운로드합니다",
-    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "이 공개 달력은 서버 관리자의 추천입니다. 달력 데이터는 각각의 웹사이트로부터 다운로드됩니다.",
     "By {authors}" : "{authors} 작성",
     "Subscribed" : "구독함",
     "Subscribe" : "구독",
@@ -411,17 +412,18 @@ OC.L10N.register(
     "Personal" : "개인",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "자동으로 감지된 귀하의 시간대가 UTC입니다.\n이 웹 브라우저의 보안 설정이 원인일 수 있습니다.\n달력 설정에서 수동으로 시간대를 설정해 주십시오.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "설정된 시간대 ({timezoneId}) 을(를) 찾을 수 없습니다. UTC로 설정됩니다.\n설정에서 시간대를 변경하고 이 문제를 보고해 주십시오.",
+    "Edit event" : "일정 편집",
     "Event does not exist" : "일정이 존재하지 않음",
     "Duplicate" : "복제",
     "Delete this occurrence" : "이 일정 삭제",
     "Delete this and all future" : "이후 모든 일정 삭제",
-    "Details" : "자세한 정보",
+    "All day" : "하루 종일",
     "Deny access" : "접근 거부",
     "Invite" : "초대",
-    "Resources" : "자원",
     "_User requires access to your file_::_Users require access to your file_" : ["사용자가 내 파일에 대한 접근을 요구합니다"],
     "Untitled event" : "제목없는 일정",
     "Close" : "닫기",
+    "Participants" : "참가자",
     "Subscribe to {name}" : "{name} 구독",
     "Export {name}" : "{name} 내보내기",
     "Anniversary" : "기념일",
