@@ -4,6 +4,7 @@ OC.L10N.register(
     "Cheers!" : "Prost!",
     "Calendar" : "Kalenner",
     "Confirm" : "Konfirméieren",
+    "Location:" : "Uert:",
     "Today" : "Haut",
     "Day" : "Dag",
     "Week" : "Woch",
@@ -64,7 +65,6 @@ OC.L10N.register(
     "Other" : "Aner",
     "When shared show full event" : "Wann et gedeelt gouf, dann de ganzen Evenement uweisen",
     "When shared show only busy" : "Wann et gedeelt gouf, dann nëmmen als beschäftegt uweisen",
-    "When shared hide this event" : "Wann et gedeelt gouf, dann verstopp dëst Evenement",
-    "Details" : "Detailer"
+    "When shared hide this event" : "Wann et gedeelt gouf, dann verstopp dëst Evenement"
 },
 "nplurals=2; plural=(n != 1);");
