@@ -25,6 +25,8 @@ OC.L10N.register(
     "Date:" : "Data:",
     "Where:" : "Kur:",
     "Comment:" : "Komentaras:",
+    "Location:" : "Vieta:",
+    "Duration:" : "Trukmė:",
     "A Calendar app for Nextcloud" : "Kalendoriaus programėlė, skirta Nextcloud",
     "Previous day" : "Ankstesnė diena",
     "Previous week" : "Ankstesnė savaitė",
@@ -122,6 +124,7 @@ OC.L10N.register(
     "Share calendar" : "Bendrinti kalendorių",
     "Unshare from me" : "Nustoti bendrinti su manimi",
     "Save" : "Įrašyti",
+    "View" : "Rodyti",
     "Import calendars" : "Importuoti kalendorius",
     "Please select a calendar to import into …" : "Pasirinkite kalendorių į kurį importuoti…",
     "Filename" : "Failo pavadinimas",
@@ -208,7 +211,6 @@ OC.L10N.register(
     "Your email address" : "Jūsų el. pašto adresas",
     "Please share anything that will help prepare for our meeting" : "Pasidalinkite informacija, kuri padės mums pasiruošti šiam susitikimui",
     "Back" : "Atgal",
-    "Create a new conversation" : "Sukurti naują pokalbį",
     "on" : "šiomis dienomis",
     "at" : ",",
     "before at" : "prieš įvykį, ties",
@@ -312,6 +314,8 @@ OC.L10N.register(
     "Update this occurrence" : "Atnaujinti šį pasikartojimą",
     "Public calendar does not exist" : "Viešojo kalendoriaus nėra",
     "Maybe the share was deleted or has expired?" : "Galbūt, viešinys buvo ištrintas arba nebegalioja?",
+    "Maybe" : "Galbūt",
+    "Create" : "Sukurti",
     "from {formattedDate}" : "nuo {formattedDate}",
     "to {formattedDate}" : "iki {formattedDate}",
     "on {formattedDate}" : "{formattedDate}",
@@ -341,6 +345,8 @@ OC.L10N.register(
     "All day" : "Visą dieną",
     "Untitled event" : "Įvykis be pavadinimo",
     "Close" : "Užverti",
+    "Selected" : "Pasirinkta",
+    "Participants" : "Dalyviai",
     "Subscribe to {name}" : "Prenumeruoti {name}",
     "Export {name}" : "Eksportuoti {name}",
     "Show availability" : "Rodyti prieinamumą",
@@ -430,11 +436,6 @@ OC.L10N.register(
     "Imported {filename}" : "Importuotas {filename}",
     "This is an event reminder." : "Tai priminimas apie įvykį.",
     "Appointment not found" : "Susitikimas nerastas",
-    "User not found" : "Naudotojas nerastas",
-    "Reminder" : "Priminimas",
-    "+ Add reminder" : "+ Pridėti priminimą",
-    "Available times:" : "Prieinami laikai:",
-    "Suggestions" : "Pasiūlymai",
-    "Details" : "Išsamiau"
+    "User not found" : "Naudotojas nerastas"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
