@@ -41,6 +41,7 @@ OC.L10N.register(
     "Comment:" : "Kommentar:",
     "You have a new appointment booking \"%s\" from %s" : "Du har en ny timebestilling \"%s\" fra %s",
     "Dear %s, %s (%s) booked an appointment with you." : "Kjære %s, %s (%s) bestilte time hos deg.",
+    "Location:" : "Sted:",
     "A Calendar app for Nextcloud" : "En kalender til Nextcloud",
     "Previous day" : "Forrige dag",
     "Previous week" : "Forrige uke",
@@ -146,6 +147,8 @@ OC.L10N.register(
     "Share calendar" : "Del kalender",
     "Unshare from me" : "Fjern deling fra meg",
     "Save" : "Lagre",
+    "No title" : "Ingen tittel",
+    "View" : "Vis",
     "Import calendars" : "Importer kalendere",
     "Please select a calendar to import into …" : "Vennligst velg en kalender å importere til ...",
     "Filename" : "Filnavn",
@@ -251,7 +254,6 @@ OC.L10N.register(
     "Please share anything that will help prepare for our meeting" : "Vennligst del alt som vil hjelpe deg med å forberede møtet vårt",
     "Could not book the appointment. Please try again later or contact the organizer." : "Kunne ikke bestille time. Prøv igjen senere eller kontakt arrangøren.",
     "Back" : "Tilbake",
-    "Create a new conversation" : "Opprett en ny samtale",
     "Select conversation" : "Velg samtale",
     "on" : "på",
     "at" : "ved",
@@ -393,6 +395,8 @@ OC.L10N.register(
     "Update this occurrence" : "Oppdater denne hendelsen",
     "Public calendar does not exist" : "Offentlig kalender finnes ikke",
     "Maybe the share was deleted or has expired?" : "Er deling slettet eller utløpt?",
+    "Maybe" : "Kanskje",
+    "Create" : "Opprett",
     "from {formattedDate}" : "fra {formattedDate}",
     "to {formattedDate}" : "til {formattedDate}",
     "on {formattedDate}" : "den {formattedDate}",
@@ -416,7 +420,6 @@ OC.L10N.register(
     "No valid public calendars configured" : "Ingen gyldige offentlige kalendere er konfigurert",
     "Speak to the server administrator to resolve this issue." : "Snakk med serveradministratoren for å løse dette problemet.",
     "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Helligdagskalendere er levert av Thunderbird. Kalenderdata vil bli lastet ned fra {website}.",
-    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "Disse offentlige kalenderne er foreslått av serveradministratoren. Kalenderdata vil bli lastet ned fra den respektive nettsiden.",
     "By {authors}" : "Av {authors}",
     "Subscribed" : "Abonnerer",
     "Subscribe" : "Abonner",
@@ -451,6 +454,7 @@ OC.L10N.register(
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Vedlegg som krever delt tilgang","Vedlegg som krever delt tilgang"],
     "Untitled event" : "Hendelse uten tittel",
     "Close" : "Lukk",
+    "Participants" : "Deltakere",
     "Subscribe to {name}" : "Abonner på {name}",
     "Export {name}" : "Eksporter {name}",
     "Anniversary" : "Jubileum",
@@ -543,13 +547,6 @@ OC.L10N.register(
     "This is an event reminder." : "Dette er en hendelsespåminnelse.",
     "Error while parsing a PROPFIND error" : "Feil under analyse av en PROPFIND-feil",
     "Appointment not found" : "Avtale ikke funnet",
-    "User not found" : "Fant ikke brukeren",
-    "Reminder" : "Påminnelse",
-    "+ Add reminder" : "+ Legg til påminnelse",
-    "Select automatic slot" : "Velg automatisk luke",
-    "with" : "med",
-    "Available times:" : "Tilgjengelige tidspunkter:",
-    "Suggestions" : "Forslag",
-    "Details" : "Detaljer"
+    "User not found" : "Fant ikke brukeren"
 },
 "nplurals=2; plural=(n != 1);");
