@@ -8,6 +8,7 @@ OC.L10N.register(
     "Cheers!" : "Tudelu!",
     "Calendar" : "Kalender",
     "Prepare for %s" : "Klargjer for %s",
+    "Location:" : "Plassering:",
     "Today" : "I dag",
     "Day" : "Dag",
     "Week" : "Veke",
@@ -52,10 +53,12 @@ OC.L10N.register(
     "never" : "aldri",
     "after" : "etter",
     "Room type" : "Romtype",
+    "Remove participant" : "Eksterne deltakarar",
     "Global" : "Global",
     "Personal" : "Personleg",
-    "Details" : "Detaljar",
+    "Edit event" : "Rediger hending",
     "Close" : "Lukk",
+    "Participants" : "Deltakarar",
     "Daily" : "Kvar dag",
     "Weekly" : "Kvar veke",
     "second" : "andre",
