@@ -11,6 +11,7 @@ OC.L10N.register(
     "Description:" : "Descripcion :",
     "Date:" : "Data :",
     "Where:" : "Ont :",
+    "Location:" : "Localizacion :",
     "A Calendar app for Nextcloud" : "Una aplicacion de calendièr per Nextcloud",
     "Previous day" : "Jorn passat",
     "Previous week" : "Setmana passada",
@@ -49,6 +50,7 @@ OC.L10N.register(
     "Deleting share link …" : "Supression del ligam de partatge …",
     "can edit" : "pòt modificar",
     "Save" : "Salvar",
+    "View" : "Veire",
     "Import calendars" : "Importar de calendièrs",
     "Filename" : "Nom de fichièr",
     "Cancel" : "Anullar",
@@ -79,7 +81,6 @@ OC.L10N.register(
     "Sunday" : "Dimenge",
     "Your name" : "Vòstre nom",
     "Your email address" : "Vòstra adreça electronica",
-    "Create a new conversation" : "Crear una conversacion novèla",
     "Select conversation" : "Seleccionar una conversacion",
     "on" : "lo",
     "at" : "a",
@@ -127,6 +128,8 @@ OC.L10N.register(
     "unavailable" : "indisponible",
     "Room type" : "Tipe de sala",
     "Any" : "Quina que siá",
+    "Remove participant" : "Tirar participant",
+    "Create" : "Crear",
     "from {formattedDate}" : "a partir de {formattedDate}",
     "to {formattedDate}" : "cap a {formattedDate}",
     "Pick a time" : "Causir una ora",
@@ -139,6 +142,9 @@ OC.L10N.register(
     "All day" : "Tota la jornada",
     "Untitled event" : "Eveniment sens nom",
     "Close" : "Tampar",
+    "Selected" : "Seleccionat",
+    "Title" : "Títol",
+    "Participants" : "Participants",
     "Anniversary" : "Anniversari",
     "Appointment" : "Rendetz-vos",
     "Business" : "Afar",
@@ -170,10 +176,6 @@ OC.L10N.register(
     "Categories" : "Categorias",
     "Custom color" : "Color personalizada",
     "Error while sharing file" : "Error pendent lo partiment del fichièr",
-    "User not found" : "Utilizaire pas trobat",
-    "Reminder" : "Recòrd",
-    "+ Add reminder" : "+ Apondre un rapèl",
-    "Suggestions" : "Suggestions",
-    "Details" : "Detalhs"
+    "User not found" : "Utilizaire pas trobat"
 },
 "nplurals=2; plural=(n > 1);");
