@@ -32,6 +32,8 @@ OC.L10N.register(
     "Where:" : "Local:",
     "Comment:" : "Comentário:",
     "You have a new appointment booking \"%s\" from %s" : "Tem uma nova reserva de marcação \"%s\" de %s",
+    "Location:" : "Localização:",
+    "Duration:" : "Duração:",
     "A Calendar app for Nextcloud" : "Uma aplicação de calendário para o Nextcloud",
     "Previous day" : "Dia anterior",
     "Previous week" : "Semana anterior",
@@ -118,6 +120,7 @@ OC.L10N.register(
     "Share calendar" : "Partilhar calendário",
     "Unshare from me" : "Cancelar partilha",
     "Save" : "Guardar",
+    "View" : "Ver",
     "Import calendars" : "Importar calendários",
     "Please select a calendar to import into …" : "Selecione o calendário para onde importar ...",
     "Filename" : "Nome do ficheiro",
@@ -163,7 +166,12 @@ OC.L10N.register(
     "Copy iOS/macOS CalDAV address" : "Copiar endereço iOS/macOS CalDAV",
     "Personal availability settings" : "Configurações de disponibilidade pessoal",
     "Show keyboard shortcuts" : "Mostrar atalhos de teclado",
+    "_{duration} minute_::_{duration} minutes_" : ["{duration} minuto","{duration} minutos","{duration} minutos"],
     "0 minutes" : "0 minutos",
+    "_{duration} hour_::_{duration} hours_" : ["{duration} hora","{duration} horas","{duration} horas"],
+    "_{duration} day_::_{duration} days_" : ["{duration} dia","{duration} dias","{duration} dias"],
+    "_{duration} month_::_{duration} months_" : ["{duration} mês","{duration} meses","{duration} meses"],
+    "_{duration} year_::_{duration} years_" : ["{duration} ano","{duration} anos","{duration} anos"],
     "To configure appointments, add your email address in personal settings." : "Para configurar reuniões, adicione seu o endereço de e-mail nas configurações pessoais.",
     "Public – shown on the profile page" : "Público - mostrado na página de perfil",
     "Private – only accessible via secret link" : "Privado - acessível apenas por ligação secreta",
@@ -177,6 +185,7 @@ OC.L10N.register(
     "Additional calendars to check for conflicts" : "Calendários adicionais para verificar conflitos",
     "Pick time ranges where appointments are allowed" : "Escolha os intervalos de tempo onde as reuniões são permitidas",
     "to" : "Para",
+    "Delete slot" : "Delete slot",
     "No times set" : "Nenhum horário definido",
     "Add" : "Adicionar",
     "Monday" : "Segunda",
@@ -186,6 +195,7 @@ OC.L10N.register(
     "Friday" : "Sexta",
     "Saturday" : "Sábado",
     "Sunday" : "Domingo",
+    "Weekdays" : "Weekdays",
     "Add time before and after the event" : "Adicionar um tempo antes e depois do evento",
     "Before the event" : "Antes do evento",
     "After the event" : "Depois do evento",
@@ -197,10 +207,8 @@ OC.L10N.register(
     "Please share anything that will help prepare for our meeting" : "Por favor partilhe qualquer coisa que ajude na preparação da nossa reunião",
     "Could not book the appointment. Please try again later or contact the organizer." : "Não foi possível agendar a reunião. Tente novamente mais tarde ou entre em contacto com o organizador.",
     "Back" : "Voltar",
-    "Create a new conversation" : "Criar nova conversa",
     "on" : "em",
     "at" : "às",
-    "Reminder" : "Lembrete",
     "before at" : "antes em",
     "Notification" : "Notificação",
     "Email" : "E-mail",
@@ -211,7 +219,6 @@ OC.L10N.register(
     "Edit time" : "Editar horário",
     "Save time" : "Gravar horário",
     "Remove reminder" : "Apagar lembrete",
-    "+ Add reminder" : "+ Adicionar lembrete",
     "Add reminder" : "Adicionar lembrete ",
     "seconds" : "segundos",
     "minutes" : "minutos",
@@ -229,12 +236,13 @@ OC.L10N.register(
     "Not available" : "Indisponível",
     "Invitation declined" : "Convite recusado",
     "Checking availability" : "A verificar disponibilidade",
-    "Free" : "Livre",
-    "Busy" : "Ocupado",
     "Out of office" : "Fora do escritório",
-    "Unknown" : "Desconhecido",
+    "Attendees:" : "Participantes:",
     "Done" : "Concluído",
     "Room name" : "Nome da sala",
+    "Free" : "Livre",
+    "Busy" : "Ocupado",
+    "Unknown" : "Desconhecido",
     "The invitation has been accepted successfully." : "O convite foi aceite com sucesso.",
     "Failed to accept the invitation." : "Falha ao aceitar o convite.",
     "The invitation has been declined successfully." : "O convite foi recusado com sucesso.",
@@ -244,7 +252,6 @@ OC.L10N.register(
     "Attendees" : "Participantes",
     "From" : "De",
     "To" : "Para",
-    "All day" : "Todo o dia",
     "Repeat" : "Repetir",
     "never" : "nunca",
     "after" : "depois",
@@ -258,16 +265,22 @@ OC.L10N.register(
     "_year_::_years_" : ["ano","anos","anos"],
     "weekday" : "dia da semana",
     "weekend day" : "dia do fim-de-semana",
+    "Resources" : "Recursos",
     "available" : "disponível",
+    "Create" : "Criar",
     "Pick a date" : "Escolha uma data",
     "Global" : "Global",
     "Subscribed" : "Subscrito",
     "Subscribe" : "Subscrever",
     "Personal" : "Pessoal",
-    "Details" : "Detalhes",
+    "Edit event" : "Editar evento",
+    "All day" : "Todo o dia",
     "Invite" : "Convite",
-    "Resources" : "Recursos",
+    "Untitled event" : "Evento sem título",
     "Close" : "Fechar",
+    "Selected" : "Selecionado",
+    "Title" : "Título",
+    "Participants" : "Participantes",
     "Anniversary" : "Aniversário",
     "Miscellaneous" : "Diversos",
     "Week {number} of {year}" : "Semana {number} do {year}",
@@ -279,6 +292,7 @@ OC.L10N.register(
     "fifth" : "quinto",
     "second to last" : "do segundo ao último",
     "last" : "ultimo",
+    "Untitled task" : "Untitled task",
     "Other" : "Outro",
     "When shared show full event" : "Quando partilhado, mostrar evento completo",
     "When shared show only busy" : "Quando partilhado, mostrar apenas ocupados",
