@@ -10,6 +10,7 @@ OC.L10N.register(
     "Description:" : "විස්තරය",
     "Date:" : "දිනය:",
     "Where:" : "කොහේද:",
+    "Location:" : "ස්ථානය:",
     "A Calendar app for Nextcloud" : "නෙක්ස්ට් ක්ලවුඩ් සඳහා දින දර්ශන යෙදුමකි",
     "Previous day" : "පසුගිය දිනය",
     "Previous week" : "පසුගිය සතිය",
@@ -52,13 +53,14 @@ OC.L10N.register(
     "Unknown" : "නොදන්නා",
     "Accept" : "පිළිගන්න",
     "Decline" : "ප්‍රතික්ෂේප",
+    "Create" : "සාදන්න",
     "Time:" : "වේලාව:",
     "Personal" : "පුද්ගලික",
     "Close" : "වසන්න",
+    "Selected" : "තෝරා ඇත",
     "Anniversary" : "සංවත්සරය",
     "Daily" : "දිනපතා",
     "Weekly" : "සතිපතා",
-    "Other" : "වෙනත්",
-    "Details" : "විස්තර"
+    "Other" : "වෙනත්"
 },
 "nplurals=2; plural=(n != 1);");
