@@ -38,6 +38,8 @@ OC.L10N.register(
     "You will receive a link with the confirmation email" : "Prejeli boste elektronsko sporočilo z overitveno povezavo",
     "Where:" : "Kje:",
     "Comment:" : "Opomba",
+    "Location:" : "Mesto:",
+    "Duration:" : "Trajanje:",
     "A Calendar app for Nextcloud" : "Program za urejanje koledarja Nextcloud",
     "Previous day" : "Predhodni dan",
     "Previous week" : "Predhodni teden",
@@ -142,6 +144,8 @@ OC.L10N.register(
     "Share calendar" : "Omogoči souporabo koledarja",
     "Unshare from me" : "Prekini souporabo",
     "Save" : "Shrani",
+    "No title" : "Ni naslova",
+    "View" : "Pogled",
     "Import calendars" : "Uvozi koledarje",
     "Please select a calendar to import into …" : "Izberite koledar za uvoz ...",
     "Filename" : "Ime datoteke",
@@ -245,7 +249,6 @@ OC.L10N.register(
     "Please share anything that will help prepare for our meeting" : "Pošljite vse predloge in dokumente, ki so pomembni pri pripravi na srečanje.",
     "Could not book the appointment. Please try again later or contact the organizer." : "Sestanka ni mogoče rezervirati. Poskusite znova kasneje oziroma stopite v stik z organizatorjem.",
     "Back" : "Nazaj",
-    "Create a new conversation" : "Ustvari nov pogovor",
     "Select conversation" : "pogovora",
     "on" : "na",
     "at" : "ob",
@@ -375,6 +378,10 @@ OC.L10N.register(
     "Update this occurrence" : "Posodobi to pojavitev",
     "Public calendar does not exist" : "Javni koledar ne obstaja",
     "Maybe the share was deleted or has expired?" : "Morda je mesto souporabe izbrisano ali je časovno poteklo.",
+    "Remove participant" : "Odstrani udeležence",
+    "Yes" : "Da",
+    "Maybe" : "Morda",
+    "Create" : "Ustvari",
     "from {formattedDate}" : "od {formattedDate}",
     "to {formattedDate}" : "do {formattedDate}",
     "on {formattedDate}" : "na {formattedDate}",
@@ -427,6 +434,9 @@ OC.L10N.register(
     "Invite" : "Povabi",
     "Untitled event" : "Neimenovan dogodek",
     "Close" : "Zapri",
+    "Selected" : "Izbrano",
+    "Title" : "Naslov",
+    "Participants" : "Udeleženci",
     "Subscribe to {name}" : "Naroči na {name}",
     "Export {name}" : "Izvozi {name}",
     "Anniversary" : "Obletnica",
@@ -516,12 +526,6 @@ OC.L10N.register(
     "Imported {filename}" : "Uvožena datoteka {filename}",
     "This is an event reminder." : "To je opomnik dogodka.",
     "Appointment not found" : "Sestanka ni mogoče najti",
-    "User not found" : "Uporabnika ni mogoče najti",
-    "Reminder" : "Opomnik",
-    "+ Add reminder" : "+ Dodaj opomnik",
-    "with" : "z",
-    "Available times:" : "Razpoložljivi termini",
-    "Suggestions" : "Predlogi",
-    "Details" : "Podrobnosti"
+    "User not found" : "Uporabnika ni mogoče najti"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
