@@ -41,6 +41,7 @@ OC.L10N.register(
     "Comment:" : "Kommentar:",
     "You have a new appointment booking \"%s\" from %s" : "Du har en ny mötesbokning \"%s\" från %s",
     "Dear %s, %s (%s) booked an appointment with you." : "%s, %s (%s) bokade ett möte med dig.",
+    "Location:" : "Ort:",
     "A Calendar app for Nextcloud" : "En kalender-app för Nextcloud",
     "Previous day" : "Föregående dag",
     "Previous week" : "Föregående vecka",
@@ -147,6 +148,7 @@ OC.L10N.register(
     "Share calendar" : "Dela kalender",
     "Unshare from me" : "Sluta dela från mig",
     "Save" : "Spara",
+    "View" : "Visa",
     "Import calendars" : "Importera kalendrar",
     "Please select a calendar to import into …" : "Vänligen välj en kalender du vill importera till …",
     "Filename" : "Filnamn",
@@ -423,6 +425,9 @@ OC.L10N.register(
     "Update this occurrence" : "Uppdatera denna förekomst",
     "Public calendar does not exist" : "Publik kalender finns inte",
     "Maybe the share was deleted or has expired?" : "Kanske har delningen tagits bort eller har gått ut?",
+    "Yes" : "Ja",
+    "Maybe" : "Kanske",
+    "Create" : "Skapa",
     "from {formattedDate}" : "från {formattedDate}",
     "to {formattedDate}" : "till {formattedDate}",
     "on {formattedDate}" : "på {formattedDate}",
@@ -486,6 +491,8 @@ OC.L10N.register(
     "Untitled event" : "Namnlös händelse",
     "Close" : "Stäng",
     "Modifications will not get propagated to the organizer and other attendees" : "Ändringar kommer inte att skickas till organisatören eller andra deltagare",
+    "Title" : "Titel",
+    "Participants" : "Deltagare",
     "Subscribe to {name}" : "Prenumerera på {name}",
     "Export {name}" : "Exportera {name}",
     "Show availability" : "Visa tillgänglighet",
@@ -589,14 +596,6 @@ OC.L10N.register(
     "This is an event reminder." : "Detta är en händelsepåminnelse.",
     "Error while parsing a PROPFIND error" : "Fel vid analys av ett PROPFIND-fel",
     "Appointment not found" : "Mötet hittades inte",
-    "User not found" : "Användaren hittades inte",
-    "Create a new conversation" : "Skapa en ny konversation",
-    "Reminder" : "Påminnelse",
-    "+ Add reminder" : "+ Lägg till påminnelse",
-    "Select automatic slot" : "Välj automatisk lucka",
-    "with" : "med",
-    "Available times:" : "Tillgängliga tider:",
-    "Suggestions" : "Rekommendationer",
-    "Details" : "Detaljer"
+    "User not found" : "Användaren hittades inte"
 },
 "nplurals=2; plural=(n != 1);");
