@@ -41,6 +41,7 @@ OC.L10N.register(
     "Comment:" : "باھا:",
     "You have a new appointment booking \"%s\" from %s" : "سىزدە% s دىن «% s» نى زاكاز قىلىش يېڭى زاكاس تالونى بار",
     "Dear %s, %s (%s) booked an appointment with you." : "ھۆرمەتلىك% s ،% s (% s) سىز بىلەن كۆرۈشۈشنى زاكاز قىلدى.",
+    "Location:" : "ئورنى:",
     "A Calendar app for Nextcloud" : "Nextcloud ئۈچۈن كالېندار دېتالى",
     "Previous day" : "ئالدىنقى كۈن",
     "Previous week" : "ئالدىنقى ھەپتە",
@@ -144,6 +145,7 @@ OC.L10N.register(
     "Share calendar" : "كالېندارنى ئورتاقلىشىش",
     "Unshare from me" : "مەندىن تەڭداشسىز",
     "Save" : "ساقلا",
+    "View" : "كۆرۈش",
     "Import calendars" : "كالېندار ئەكىرىڭ",
     "Please select a calendar to import into …" : "ئىمپورت قىلىدىغان كالېندارنى تاللاڭ.",
     "Filename" : "ھۆججەت ئىسمى",
@@ -245,7 +247,6 @@ OC.L10N.register(
     "Please share anything that will help prepare for our meeting" : "ئۇچرىشىشىمىزغا تەييارلىق قىلىشقا ياردىمى بولىدىغان نەرسىلەرنى ئورتاقلىشىڭ",
     "Could not book the appointment. Please try again later or contact the organizer." : "ئۇچرىشىشنى زاكاز قىلالمىدى. كېيىن قايتا سىناڭ ياكى تەشكىللىگۈچى بىلەن ئالاقىلىشىڭ.",
     "Back" : "قايتىش",
-    "Create a new conversation" : "يېڭى سۆھبەت قۇر",
     "Select conversation" : "سۆھبەتنى تاللاڭ",
     "on" : "on",
     "at" : "at",
@@ -378,6 +379,11 @@ OC.L10N.register(
     "Update this occurrence" : "بۇ ھادىسىنى يېڭىلاڭ",
     "Public calendar does not exist" : "ئاممىۋى كالېندار مەۋجۇت ئەمەس",
     "Maybe the share was deleted or has expired?" : "بەلكىم ھەمبەھىر ئۆچۈرۈلگەن ياكى ۋاقتى توشقان بولۇشى مۇمكىن؟",
+    "Remove participant" : "قاتناشقۇچىنى ئېلىۋېتىڭ",
+    "Yes" : "ھەئە",
+    "No" : "ياق",
+    "Maybe" : "مۇمكىن",
+    "Create" : "قۇر",
     "from {formattedDate}" : "from {formattedDate}",
     "to {formattedDate}" : "to {formattedDate}",
     "on {formattedDate}" : "on {formattedDate}",
@@ -401,7 +407,6 @@ OC.L10N.register(
     "No valid public calendars configured" : "ئىناۋەتلىك ئاممىۋى كالېندار سەپلەنمىدى",
     "Speak to the server administrator to resolve this issue." : "بۇ مەسىلىنى ھەل قىلىش ئۈچۈن مۇلازىمېتىر باشقۇرغۇچىغا سۆزلەڭ.",
     "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "ئاممىۋى دەم ئېلىش كالېندارىنى Thunderbird تەمىنلەيدۇ. كالېندار سانلىق مەلۇماتلىرى {website} بېكىتى} دىن چۈشۈرۈلىدۇ",
-    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "بۇ ئاممىۋى كالېندارلارنى كەسمە باشقۇرغۇچى تەۋسىيە قىلىدۇ. كالېندار سانلىق مەلۇماتلىرى مۇناسىۋەتلىك تور بەتتىن چۈشۈرۈلىدۇ.",
     "By {authors}" : "{authors}",
     "Subscribed" : "مۇشتەرى بولدى",
     "Subscribe" : "مۇشتەرى بولۇش",
@@ -433,6 +438,9 @@ OC.L10N.register(
     "Invite" : "تەكلىپ قىلىڭ",
     "Untitled event" : "نامسىز ھادىسە",
     "Close" : "ياپ",
+    "Selected" : "تاللانغان",
+    "Title" : "ماۋزۇ",
+    "Participants" : "قاتناشقۇچىلار",
     "Subscribe to {name}" : "{name} غا مۇشتەرى بولۇڭ",
     "Export {name}" : "چىقىرىش {name}",
     "Anniversary" : "يىللىق خاتىرە كۈنى",
@@ -514,13 +522,6 @@ OC.L10N.register(
     "This is an event reminder." : "بۇ بىر ۋەقە ئەسكەرتىش.",
     "Error while parsing a PROPFIND error" : "PROPFIND خاتالىقىنى تەھلىل قىلغاندا خاتالىق",
     "Appointment not found" : "تەيىنلەنمىدى",
-    "User not found" : "ئىشلەتكۈچى تېپىلمىدى",
-    "Reminder" : "ئەسكەرتىش",
-    "+ Add reminder" : "+ ئەسكەرتىش قوشۇڭ",
-    "Select automatic slot" : "ئاپتوماتىك ئورۇننى تاللاڭ",
-    "with" : "with",
-    "Available times:" : "ئىشلەتكىلى بولىدىغان ۋاقىت:",
-    "Suggestions" : "تەكلىپ",
-    "Details" : "تەپسىلاتى"
+    "User not found" : "ئىشلەتكۈچى تېپىلمىدى"
 },
 "nplurals=2; plural=(n != 1);");
