@@ -36,6 +36,7 @@ OC.L10N.register(
     "Comment:" : "Bình luận",
     "You have a new appointment booking \"%s\" from %s" : "Bạn có lịch hẹn mới được book bởi \"%s\" vào lúc %s",
     "Dear %s, %s (%s) booked an appointment with you." : "Gửi %s,%s(%s) đã book lịch hẹn với bạn.",
+    "Location:" : "Đến từ :",
     "A Calendar app for Nextcloud" : "Một ứng dụng Lịch nhắc nhở cho Hệ thống",
     "Previous day" : "Ngày trước",
     "Previous week" : "Tuần trước",
@@ -119,6 +120,7 @@ OC.L10N.register(
     "No users or groups" : "Không có người dùng hay nhóm",
     "Unshare from me" : "Gỡ chia sẻ khỏi tôi",
     "Save" : "Lưu",
+    "View" : "Xem",
     "Import calendars" : "Nhập lịch",
     "Please select a calendar to import into …" : "Vui lòng chọn một lịch để nhập vào  …",
     "Filename" : "Tên tập tin",
@@ -308,6 +310,9 @@ OC.L10N.register(
     "Update this occurrence" : "Cập nhập định kỳ này",
     "Public calendar does not exist" : "Lịch công khai không tồn tại",
     "Maybe the share was deleted or has expired?" : "Có lẽ chia sẽ đã bị xóa hoặc hết hạn ? ",
+    "Yes" : "Có",
+    "No" : "Không",
+    "Create" : "Tạo",
     "from {formattedDate}" : "từ {formattedDate}",
     "to {formattedDate}" : "đến {formattedDate}",
     "on {formattedDate}" : "vào {formattedDate}",
@@ -348,6 +353,8 @@ OC.L10N.register(
     "Invite" : "Mời",
     "Untitled event" : "Sự kiện không tiêu đề",
     "Close" : "Đóng",
+    "Title" : "Tên",
+    "Participants" : "Người tham gia",
     "Subscribe to {name}" : "Dõi theo {name}",
     "Export {name}" : "Xuất dữ liệu bảng {name}",
     "Anniversary" : "Ngày kỷ niệm",
@@ -433,10 +440,6 @@ OC.L10N.register(
     "An error occurred, unable to delete the calendar." : "Một lỗi đã xảy ra, không thể xóa lịch.",
     "Imported {filename}" : " {filename} đã được nhập",
     "Appointment not found" : "Không tìm thấy cuộc hẹn",
-    "User not found" : "Không tìm thấy người dùng",
-    "Reminder" : "Lịch nhắc hẹn",
-    "+ Add reminder" : "+ Thêm lịch nhắc hẹn",
-    "Suggestions" : "Các đề suất",
-    "Details" : "Chi tiết"
+    "User not found" : "Không tìm thấy người dùng"
 },
 "nplurals=1; plural=0;");
